%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Microstructure Diffusion Toolbox
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

############
Introduction
############

.. include:: ../README.rst
   :start-line: 3


.. toctree::
    :maxdepth: 2
    :hidden:

    install
    using_mdt
    mle_fitting
    mcmc_sampling
    adding_components
    maps_visualizer
    concepts
    configuration
    FAQ <faq>
    scientific_articles
    credits
